/* exportingDialog.h

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#ifndef EXPORTINGDIALOG_H
#define EXPORTINGDIALOG_H

#include "palomaDialog.h"
#include "shellCommand.h"


#include <gtk--.h>
#include <string>
#include <time.h>

class PlaylistProxy;

class ExportingDialog : public PalomaDialog {
public:
  ExportingDialog(const Dataset &data, 
		  const PlaylistProxy &playlist, int start_row,
		  bool symlink, int convert_type,
		  const string &root_dir,
		  const string &filename_pattern,
		  double max_time);
  ~ExportingDialog();

  void export_success();
  void export_failure();

private:
  void cancel_button_clicked();
  gint delete_timeout();
  int back_from_idle();

  void layout_window();
  bool advance();
  bool export_current();
  void start_exporting(const TableDataProxy &song, 
		       const string &filename_to);

  static string make_filename_friendly(const string &orig_name);

  Gtk_VBox _box1;
  Gtk_Label _title;
  Gtk_ProgressBar _progress_bar;
  Gtk_Label _song_name;
  Gtk_Button _cancel_button;

  bool _symlink;
  int _convert_type;
  string _root_dir;
  string _filename_pattern;
  double _max_time;

  class Entry {
  public:
    int _song_id;
    int _cd_id;
  };

  typedef vector<Entry> Entries;
  Entries _entries;

  int _current_index;
  double _total_length;
  double _current_length;
  time_t _last_return;

  ShellCommand _shell;
  bool _canceled;
};

#endif
  
  
