/* tableField.C

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#include "system.h"

#include "tableField.h"
#include "database.h"


TableField::
TableField() {
  _field_id = -1;
  _foreign_table = TI_no_table;
}

TableField::
TableField(int field_id, DataCell::Type field_type, 
	   TableID foreign_table, const DataCell &default_value,
	   const string &field_name, const string &label) :
  _field_id(field_id), _field_type(field_type),
  _foreign_table(foreign_table), _default_value(default_value),
  _field_name(field_name), _label(label)
{
}

const DataCell &TableField::
get_default_value() const {
  return _default_value;
}

string TableField::
get_db_type() const {
  switch (_field_type) {
  case DataCell::DC_bool:
    return "BOOL";

  case DataCell::DC_int:
  case DataCell::DC_foreign_key:
    return "INT";

  case DataCell::DC_float:
  case DataCell::DC_elapsed_time:
    return "FLOAT";

  case DataCell::DC_string:
    return "TEXT";

  case DataCell::DC_timestamp:
    return "TIMESTAMP";
  }

  cerr << "Unexpected field type " << _field_type << "\n";
  abort();

  // This is just to make the compiler happy.  We'll never get here.
  return string();
}


// Insert a new record into the database.  We don't have a function
// called record_db(), because we assume the TableDef will always
// delete all of its child widgets before adding them back in.  So
// this is always an insert operation.
void TableField::
insert_db(TableID table_id) {
  assert(is_extension_table(table_id));

  if (_field_id < 0) {
    _field_id = music_db->get_next_sequence("extension_fields_field_id_seq");
  }

  music_db->sql_command
    ("INSERT INTO extension_fields (field_id, table_id, "
     "field_type, foreign_table, default_value, field_name, label) VALUES (" +
     DataCell(_field_id) + ", " +
     DataCell(table_id) + ", " +
     DataCell(_field_type) + ", " +
     DataCell(_foreign_table, _foreign_table != TI_no_table) + ", " +
     DataCell(_default_value) + ", " +
     DataCell(_field_name) + ", " +
     DataCell(_label, !_label.empty()) + ")");
}

